// -*- c++ -*-
// Generated by gmmproc 2.46.1 -- DO NOT MODIFY!
#ifndef _GOOCANVASMM_ELLIPSEMODEL_H
#define _GOOCANVASMM_ELLIPSEMODEL_H


#include <glibmm/ustring.h>
#include <sigc++/sigc++.h>

/* Copyright (C) 1998-2006 The gtkmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include <goocanvasmm/itemmodelsimple.h>


#ifndef DOXYGEN_SHOULD_SKIP_THIS
typedef struct _GooCanvasEllipseModel GooCanvasEllipseModel;
typedef struct _GooCanvasEllipseModelClass GooCanvasEllipseModelClass;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */


#ifndef DOXYGEN_SHOULD_SKIP_THIS
namespace Goocanvas
{ class EllipseModel_Class; } // namespace Goocanvas
#endif //DOXYGEN_SHOULD_SKIP_THIS

namespace Goocanvas
{


class EllipseModel : public Goocanvas::ItemModelSimple
{
  
#ifndef DOXYGEN_SHOULD_SKIP_THIS

public:
  typedef EllipseModel CppObjectType;
  typedef EllipseModel_Class CppClassType;
  typedef GooCanvasEllipseModel BaseObjectType;
  typedef GooCanvasEllipseModelClass BaseClassType;

  // noncopyable
  EllipseModel(const EllipseModel&) = delete;
  EllipseModel& operator=(const EllipseModel&) = delete;

private:  friend class EllipseModel_Class;
  static CppClassType ellipsemodel_class_;

protected:
  explicit EllipseModel(const Glib::ConstructParams& construct_params);
  explicit EllipseModel(GooCanvasEllipseModel* castitem);

#endif /* DOXYGEN_SHOULD_SKIP_THIS */

public:

  EllipseModel(EllipseModel&& src) noexcept;
  EllipseModel& operator=(EllipseModel&& src) noexcept;

  virtual ~EllipseModel() noexcept;

  /** Get the GType for this class, for use with the underlying GObject type system.
   */
  static GType get_type()      G_GNUC_CONST;

#ifndef DOXYGEN_SHOULD_SKIP_THIS


  static GType get_base_type() G_GNUC_CONST;
#endif

  ///Provides access to the underlying C GObject.
  GooCanvasEllipseModel*       gobj()       { return reinterpret_cast<GooCanvasEllipseModel*>(gobject_); }

  ///Provides access to the underlying C GObject.
  const GooCanvasEllipseModel* gobj() const { return reinterpret_cast<GooCanvasEllipseModel*>(gobject_); }

  ///Provides access to the underlying C instance. The caller is responsible for unrefing it. Use when directly setting fields in structs.
  GooCanvasEllipseModel* gobj_copy();

private:

protected:

  EllipseModel(double center_x = 0.0, double center_y = 0., double radius_x = 0.0, double radius_y = 0.0);
  

public:

  
  static Glib::RefPtr<EllipseModel> create(double center_x =  0.0, double center_y =  0.0, double radius_x =  0.0, double radius_y =  0.0);


  /** The x coordinate of the center of the ellipse.
   *
   * @return A PropertyProxy that allows you to get or set the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy< double > property_center_x() ;

/** The x coordinate of the center of the ellipse.
   *
   * @return A PropertyProxy_ReadOnly that allows you to get the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy_ReadOnly< double > property_center_x() const;

  /** The y coordinate of the center of the ellipse.
   *
   * @return A PropertyProxy that allows you to get or set the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy< double > property_center_y() ;

/** The y coordinate of the center of the ellipse.
   *
   * @return A PropertyProxy_ReadOnly that allows you to get the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy_ReadOnly< double > property_center_y() const;

  /** The horizontal radius of the ellipse.
   *
   * @return A PropertyProxy that allows you to get or set the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy< double > property_radius_x() ;

/** The horizontal radius of the ellipse.
   *
   * @return A PropertyProxy_ReadOnly that allows you to get the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy_ReadOnly< double > property_radius_x() const;

  /** The vertical radius of the ellipse.
   *
   * @return A PropertyProxy that allows you to get or set the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy< double > property_radius_y() ;

/** The vertical radius of the ellipse.
   *
   * @return A PropertyProxy_ReadOnly that allows you to get the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy_ReadOnly< double > property_radius_y() const;


public:

public:
  //C++ methods used to invoke GTK+ virtual functions:

protected:
  //GTK+ Virtual Functions (override these to change behaviour):

  //Default Signal Handlers::


};


}


namespace Glib
{
  /** A Glib::wrap() method for this object.
   * 
   * @param object The C instance.
   * @param take_copy False if the result should take ownership of the C instance. True if it should take a new copy or ref.
   * @result A C++ instance that wraps this C instance.
   *
   * @relates Goocanvas::EllipseModel
   */
  Glib::RefPtr<Goocanvas::EllipseModel> wrap(GooCanvasEllipseModel* object, bool take_copy = false);
}


#endif /* _GOOCANVASMM_ELLIPSEMODEL_H */

